@@ -40,10 +40,14 @@ from .commands.whenever import setWheneverAction
 from .commands.ssh import executeSshRequest
 from .commands.ssh import rewriteSshRequest
 from .commands.compare import executeCompareRequest
+from .commands.helper import showHelp
+from .commands.data import executeDataRequest
+from .commands.monitor import executeMonitorRequest
 
 from .common import rewriteHintStatement
 from .common import rewriteSQLStatement
 from .common import rewriteAPIStatement
+from .common import rewriteConnectRequest
 from .common import parseSQLHints
 from .common import parseAPIHints
 from .common import sortresult
@@ -234,9 +238,12 @@ class CmdExecute(object):
                         return dataValue
                     elif p_column.getColumnTypeName().upper().find("BLOB") != -1:
                         dataValue = p_column.getData(1, p_column.getObjectLength())
-                        dataValue = binascii.b2a_hex(dataValue)
-                        dataValue = dataValue.decode()
-                        return "0x" + dataValue
+                        if dataValue is not None:
+                            dataValue = binascii.b2a_hex(dataValue)
+                            dataValue = dataValue.decode()
+                            return "0x" + dataValue
+                        else:
+                            return None
                 else:
                     if p_column.getColumnTypeName().upper().find("CLOB") != -1:
                         dataValue = "Len:" + str(p_column.getObjectLength()) + ";" + \
@@ -271,7 +278,7 @@ class CmdExecute(object):
                 status = "{0} row{1} selected with warnings."
             else:
                 status = "{0} row{1} selected."
-            arraySize = int(self.testOptions.get("ARRAYSIZE"))
+            arraySize = int(self.testOptions.get("SQL_FETCHSIZE"))
             rowset = cursor.fetchmany(arraySize)
             for row in rowset:
                 collatedRow = []
@@ -424,9 +431,10 @@ class CmdExecute(object):
             body = "".join(apiRequest["contents"])
         else:
             body = ""
+        body = body.encode(self.testOptions.get("SCRIPT_ENCODING"))
         try:
             # 重置Header的Content-Length
-            headers["Content-Length"] = len(str(body))
+            headers["Content-Length"] = len(body)
             ret = httpHandler.request(
                 method=httpMethod,
                 url=httpRequestTarget,
@@ -540,9 +548,8 @@ class CmdExecute(object):
                         for sqlFilter in sqlHints["LogFilter"]:
                             for item in result[:]:
                                 if "TESTCLI_DEBUG" in os.environ:
-                                    print("[DEBUG] Apply Filter: " + str(''.join(str(item))) +
-                                          " with " + sqlFilter)
-                                if re.match(sqlFilter, ''.join(str(item)), re.IGNORECASE):
+                                    print("[DEBUG] Apply Filter: [" + str(''.join(str(item))) + "] with " + sqlFilter)
+                                if re.match(pattern=sqlFilter, string=''.join(str(item)), flags=re.IGNORECASE):
                                     result.remove(item)
                                     continue
 
@@ -642,7 +649,8 @@ class CmdExecute(object):
                                     "java.sql.SQLTransientConnectionException:",
                                     "java.sql.SQLFeatureNotSupportedException",
                                     "com.microsoft.sqlserver.jdbc.",
-                                    "org.h2.jdbc.JdbcSQLSyntaxErrorException:"
+                                    "org.h2.jdbc.JdbcSQLSyntaxErrorException:",
+                                    "dm.jdbc.driver.DMException:",
                                     ]:
                     if sqlErrorMessage.startswith(errorPrefix):
                         sqlErrorMessage = sqlErrorMessage[len(errorPrefix):].strip()
@@ -724,7 +732,6 @@ class CmdExecute(object):
             statementLines = statement.split('\n')
             for nPos in range(0, len(statementLines)):
                 statementLine = statementLines[nPos]
-
                 # 将上次没有结束的行和当前行放在一起, 再次看是否已经结束
                 if currentStatement is None:
                     currentStatement = statementLine
@@ -745,45 +752,47 @@ class CmdExecute(object):
                 else:
                     raise TestCliException("不支持的运行空间【" + str(nameSpace) + "】")
 
-                # 语句没有结束
-                if not isFinished:
-                    # 如果语句还没有结束，则需要等待下一行输入
-                    # 如果到了文件末尾，就没有必要继续等待，直接返回
-                    if nPos == (len(statementLines) - 1):
-                        if self.testOptions.get("NAMESPACE") == "SQL":
-                            ret_CommandSplitResults.append(
-                                {'name': 'SQL_UNKNOWN',
-                                 'statement': currentStatement,
-                                 'reason': "missing SQL_END at '<EOF>'"}
-                            )
-                        elif self.testOptions.get("NAMESPACE") == "API":
-                            ret_CommandSplitResults.append(
-                                {'name': 'API_UNKNOWN',
-                                 'statement': currentStatement,
-                                 'reason': "missing HTTP_END at '<EOF>'"}
-                            )
-                        # 解析前的语句
-                        ret_CommandSplitResultsWithComments.append(currentStatementWithComments)
-                        # 所有的提示信息
-                        ret_CommandHints.append(currentHints)
-                        # 清空语句的变量
-                        currentHints = []
-                        currentStatement = None
-                        currentStatementWithComments = None
-                    continue
-
-                # 语句已经结束
-                if ret_CommandSplitResult is None:
-                    # 解析的结果为空，可能的原因有：
-                    #    这是一个空行，或者仅仅包含注释，那继续等待下一个有意义的行
-                    #    这行已经发生了解析错误，但是由于我们的解析规则并不覆盖所有的数据库语句，所以就假设其为数据库语句
-                    if ret_errorCode != 0:
-                        # 语句已经出错
-                        if self.testOptions.get("NAMESPACE") == "SQL":
-                            # 对于SQL语句，不认识的语句要当作一个SQL使用
-                            #   如果语句的最后一个字符是SQL终止符号，则认为语句结束
-                            #   如果语句的最后一个字符不是SQL终止符号，继续等待
-                            if currentStatement.strip().endswith(';') or currentStatement.strip().endswith('\n/'):
+                # 如果发生了语句解析错误，且错误信息是缺少EOF，则是认为语句没有结束导致，不是正常的错误
+                if ret_errorCode != 0:
+                    missedSQLSlash = False
+                    if re.search(pattern=r'missing.*<EOF>', string=ret_errorMsg):
+                        # 语句没有结束
+                        isFinished = False
+                    if re.search(pattern=r'missing.*SQL_SLASH', string=ret_errorMsg):
+                        # 语句没有结束
+                        missedSQLSlash = True
+                        isFinished = False
+                    if re.search(pattern=r'expecting.*<EOF>', string=ret_errorMsg):
+                        # 语句没有结束
+                        isFinished = False
+                    if not isFinished and self.testOptions.get("NAMESPACE") == "SQL":
+                        statementFinished = False
+                        if nPos == (len(statementLines) - 1):
+                            # 都已经到最后一行了，不需要继续等待了
+                            statementFinished = True
+                        if currentStatement.strip().endswith(';') and not missedSQLSlash:
+                            # 遇到了分号，且不是复合语句，那么直接结束
+                            statementFinished = True
+                        if currentStatement.strip().endswith("\n/"):
+                            # 遇到了顶行的/，不管是不是复合语句，直接结束
+                            statementFinished = True
+                        if statementFinished:
+                            if currentStatement.strip().startswith("_"):
+                                # 内部语句，且语句已经结束
+                                ret_CommandSplitResults.append(
+                                    {'name': 'PARSE_ERROR',
+                                     'statement': currentStatement,
+                                     'reason': ret_errorMsg}
+                                )
+                                # 解析前的语句
+                                ret_CommandSplitResultsWithComments.append(currentStatementWithComments)
+                                # 所有的提示信息
+                                ret_CommandHints.append(currentHints)
+                                # 清空语句的变量
+                                currentHints = []
+                                currentStatement = None
+                                currentStatementWithComments = None
+                            else:
                                 ret_CommandSplitResults.append(
                                     {'name': 'SQL_UNKNOWN',
                                      'statement': currentStatement,
@@ -797,24 +806,54 @@ class CmdExecute(object):
                                 currentHints = []
                                 currentStatement = None
                                 currentStatementWithComments = None
-                            continue
+                        continue
+
+                # 如果语句没有结束，则需要等待下一句输入
+                if not isFinished:
+                    # 如果到了文件末尾，就没有必要继续等待，直接返回
+                    if nPos == (len(statementLines) - 1):
+                        if self.testOptions.get("NAMESPACE") == "SQL":
+                            ret_CommandSplitResults.append(
+                                {'name': 'SQL_UNKNOWN',
+                                 'statement': currentStatement,
+                                 'reason': ret_errorMsg}
+                            )
                         elif self.testOptions.get("NAMESPACE") == "API":
-                            # 对于API语句，不认识的语句肯定是出问题了
                             ret_CommandSplitResults.append(
                                 {'name': 'API_UNKNOWN',
                                  'statement': currentStatement,
                                  'reason': ret_errorMsg}
                             )
-                            # 解析前的语句
-                            ret_CommandSplitResultsWithComments.append(currentStatementWithComments)
-                            # 所有的提示信息
-                            ret_CommandHints.append(currentHints)
-                            # 清空语句的变量
-                            currentHints = []
-                            currentStatementWithComments = None
+                        # 解析前的语句
+                        ret_CommandSplitResultsWithComments.append(currentStatementWithComments)
+                        # 所有的提示信息
+                        ret_CommandHints.append(currentHints)
+                        # 清空语句的变量
+                        currentHints = []
+                        currentStatement = None
+                        currentStatementWithComments = None
+                    continue
 
-                    # 没有任何有效的语句，可能是空行或者完全的注释
-                    # 对于注释中的Hint信息需要保留下来
+                # 语句已经结束, 但是输入的内容有错误信息
+                if isFinished and ret_errorCode != 0:
+                    ret_CommandSplitResults.append(
+                        {'name': 'PARSE_ERROR',
+                         'statement': currentStatement,
+                         'reason': ret_errorMsg}
+                    )
+                    # 解析前的语句
+                    ret_CommandSplitResultsWithComments.append(currentStatementWithComments)
+                    # 所有的提示信息
+                    ret_CommandHints.append(currentHints)
+                    # 清空语句的变量
+                    currentHints = []
+                    currentStatement = None
+                    currentStatementWithComments = None
+                    continue
+
+                # 语句已经结束，没有任何错误，但解析的结果为空
+                if ret_CommandSplitResult is None:
+                    # 空行，可能包含注释，保留注释内容，带到下一个有意义的段落
                     # Hint的两种写法
                     # 1.  -- [Hint]  hintsomething
                     # 2.  -- [hitsomething]
@@ -827,7 +866,6 @@ class CmdExecute(object):
                         matchObj = re.match(pattern, statementLine, re.IGNORECASE)
                         if matchObj:
                             currentHints.append(matchObj.group(4).strip())
-
                     # 解析后的语句
                     ret_CommandSplitResults.append(None)
                     # 解析前的语句
@@ -838,37 +876,37 @@ class CmdExecute(object):
                     currentStatement = None
                     currentStatementWithComments = None
                     continue
-                else:
-                    # 解析出来了真实有效的内容
-                    if ret_CommandSplitResult["name"] == "USE":
-                        self.testOptions.set("NAMESPACE", ret_CommandSplitResult["nameSpace"])
-                    if self.testOptions.get("NAMESPACE") == "SQL":
-                        # 对于SQL的CONNECT命令做特殊处理
-                        if ret_CommandSplitResult["name"] == "CONNECT":
-                            # 对于数据库连接命令，如果没有给出连接详细信息，并且指定了环境变量，附属环境变量到连接命令后
-                            if "driver" not in ret_CommandSplitResult:
-                                connectionURL = None
-                                if "SQLCLI_CONNECTION_URL" in os.environ:
-                                    connectionURL = \
-                                        str(os.environ["SQLCLI_CONNECTION_URL"]).strip('"').strip("'").strip()
-                                elif "TESTCLI_CONNECTION_URL" in os.environ:
-                                    connectionURL = \
-                                        str(os.environ["TESTCLI_CONNECTION_URL"]).strip('"').strip("'").strip()
-                                if connectionURL is not None:
-                                    (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-                                        = SQLAnalyze(currentStatement + "@" + connectionURL)
-                    # 语句已经结束, 记录语句解析的结果
-                    # 解析后的语句
-                    ret_CommandSplitResults.append(ret_CommandSplitResult)
-                    # 解析前的语句
-                    ret_CommandSplitResultsWithComments.append(currentStatementWithComments)
-                    # 所有的提示信息
-                    ret_CommandHints.append(currentHints)
-                    # 清空语句的变量
-                    currentHints = []
-                    currentStatement = None
-                    currentStatementWithComments = None
-                    continue
+
+                # 切换解析的命名空间
+                if ret_CommandSplitResult["name"] == "USE":
+                    self.testOptions.set("NAMESPACE", ret_CommandSplitResult["nameSpace"])
+
+                # 对于SQL的CONNECT命令做特殊处理， 以支持外部环境变量带来的问题
+                if self.testOptions.get("NAMESPACE") == "SQL":
+                    if ret_CommandSplitResult["name"] == "CONNECT":
+                        # 对于数据库连接命令，如果没有给出连接详细信息，并且指定了环境变量，附属环境变量到连接命令后
+                        if "driver" not in ret_CommandSplitResult:
+                            connectionURL = None
+                            if "SQLCLI_CONNECTION_URL" in os.environ:
+                                connectionURL = str(os.environ["SQLCLI_CONNECTION_URL"]).strip('"').strip("'").strip()
+                            elif "TESTCLI_CONNECTION_URL" in os.environ:
+                                connectionURL = str(os.environ["TESTCLI_CONNECTION_URL"]).strip('"').strip("'").strip()
+                            if connectionURL is not None:
+                                # 拼接链接字符串后重新解析
+                                (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+                                    = SQLAnalyze(currentStatement + "@" + connectionURL)
+
+                # 语句正常结束，且其中包含了正式的内容
+                ret_CommandSplitResults.append(ret_CommandSplitResult)
+                # 解析前的语句
+                ret_CommandSplitResultsWithComments.append(currentStatementWithComments)
+                # 所有的提示信息
+                ret_CommandHints.append(currentHints)
+                # 清空语句的变量
+                currentHints = []
+                currentStatement = None
+                currentStatementWithComments = None
+                continue
         except Exception:
             if "TESTCLI_DEBUG" in os.environ:
                 print('traceback.print_exc():\n%s' % traceback.print_exc())
@@ -1021,11 +1059,19 @@ class CmdExecute(object):
                     self.scenarioId = scenarioId
 
             # 处理各种命令
+            if "TESTCLI_DEBUG" in os.environ:
+                print("[DEBUG] parsedObject=[" + str(parseObject) + "]")
             sqlKeyWords = ["SELECT", "DELETE", "UPDATE", "CREATE", "INSERT",
                            "DROP", "COMMIT", "ROLLBACK",
                            "PROCEDURE", "DECLARE", "BEGIN",
                            "SQL_UNKNOWN"]
-            if parseObject["name"] == "ECHO":
+            if parseObject["name"] == "HELP":
+                # 显示帮助信息
+                for commandResult in showHelp(
+                        topicName=parseObject["topic"],
+                ):
+                    yield commandResult
+            elif parseObject["name"] == "ECHO":
                 # 将后续内容回显到指定的文件中
                 for commandResult in echo_input(
                         cls=self.cliHandler,
@@ -1065,28 +1111,35 @@ class CmdExecute(object):
                         lastCommandResult["errorCode"] = 1
                     yield commandResult
             elif parseObject["name"] == "CONNECT":
-                # 执行CONNECT命令
-                if self.testOptions.get("NAMESPACE") == "SQL":
-                    for commandResult in connectDb(
-                            cls=self.cliHandler,
-                            connectProperties=parseObject
-                    ):
-                        if commandResult["type"] == "result":
-                            lastCommandResult.clear()
-                            lastCommandResult["status"] = commandResult["status"]
-                            lastCommandResult["errorCode"] = 0
-                        if commandResult["type"] == "error":
-                            lastCommandResult["message"] = commandResult["message"]
-                            lastCommandResult["errorCode"] = 1
-                        yield commandResult
-                else:
-                    lastCommandResult["message"] = "Not support connect command in non-sql namespace"
-                    lastCommandResult["errorCode"] = 1
+                # 根据语句中的变量或者其他定义信息来重写当前语句
+                connectRequestObject, rewrotedCommandList = rewriteConnectRequest(
+                    cls=self.cliHandler,
+                    connectRequestObject=parseObject,
+                    commandScriptFile=commandScriptFile
+                )
+                if len(rewrotedCommandList) != 0:
+                    # 如果命令被发生了改写，要打印改写记录
                     yield {
-                        "type": "error",
-                        "message": "Not support connect command in non-sql namespace",
+                        "type": "parse",
+                        "rawCommand": None,
+                        "formattedCommand": None,
+                        "rewrotedCommand": rewrotedCommandList,
                         "script": commandScriptFile
                     }
+
+                # 执行CONNECT命令
+                for commandResult in connectDb(
+                        cls=self.cliHandler,
+                        connectProperties=connectRequestObject
+                ):
+                    if commandResult["type"] == "result":
+                        lastCommandResult.clear()
+                        lastCommandResult["status"] = commandResult["status"]
+                        lastCommandResult["errorCode"] = 0
+                    if commandResult["type"] == "error":
+                        lastCommandResult["message"] = commandResult["message"]
+                        lastCommandResult["errorCode"] = 1
+                    yield commandResult
             elif parseObject["name"] == "SET":
                 # 执行SET命令
                 for commandResult in setOptions(
@@ -1416,9 +1469,21 @@ class CmdExecute(object):
                         requestObject=parseObject,
                 ):
                     yield result
-            elif parseObject["name"] in ["UNKNOWN"]:
+            elif parseObject["name"] in ["DATA"]:
+                for result in executeDataRequest(
+                        cls=self.cliHandler,
+                        requestObject=parseObject,
+                ):
+                    yield result
+            elif parseObject["name"] in ["PARSE_ERROR"]:
                 yield {"type": "error",
-                       "message": "TESTCLI_0000:  " + parseObject["reason"]}
+                       "message": "TestCli parse error:  " + str(parseObject["reason"])}
+            elif parseObject["name"] in ["MONITOR"]:
+                for result in executeMonitorRequest(
+                        cls=self.cliHandler,
+                        requestObject=parseObject,
+                ):
+                    yield result
             else:
                 raise TestCliException("FDDFSFDFSDSFD " + str(parseObject))
 
@@ -1444,7 +1509,7 @@ class CmdExecute(object):
                     "type": "statistics",
                     "startedTime": startTime,
                     "elapsed": endTime - startTime,
-                    "thread_name": self.workerName,
+                    "processName": self.workerName,
                     "rawCommand": ret_CommandSplitResultsWithComments[pos],
                     "commandType": parseObject["name"],
                     "command": json.dumps(obj=parseObject, sort_keys=True, ensure_ascii=False),
