@@ -1,22 +1,37 @@
 # -*- coding: utf-8 -*-
-from testcli.globalvar import globalEmbeddScriptScope
-from testcli.globalvar import localEmbeddScriptScope
-from testcli.globalvar import lastCommandResult
+from ..globalvar import globalEmbeddScriptScope
+from ..globalvar import localEmbeddScriptScope
+from ..globalvar import lastCommandResult
 
 
-def assertExpression(cls, expression: str):
+def assertExpression(cls, expression: str, assertName: str):
     try:
         ret = evalExpression(cls, expression)
-        if type(ret) == bool:
+        if ret:
+            if assertName is None:
+                status = "Assert successful."
+            else:
+                status = "Assert [" + assertName + "] successful."
+        else:
+            if assertName is None:
+                status = "Assert fail."
+            else:
+                status = "Assert [" + assertName + "] fail."
+        if ret:
             yield {
                 "type": "result",
                 "title": "",
                 "rows": "",
                 "headers": "",
                 "columnTypes": "",
-                "status": "Assert " + ("successful." if ret else "fail.")
+                "status": status
             }
-    except (SyntaxError, NameError, AttributeError) as ae:
+        else:
+            yield {
+                "type": "error",
+                "message": status
+            }
+    except Exception as ae:
         yield {
             "type": "error",
             "message": "Assert fail. SyntaxError =>[" + str(ae) + "]"
@@ -34,7 +49,7 @@ def evalExpression(cls, expression: str):
         "columnTypes": None,
         "status": None
     }
-    localEmbeddScriptScope["sessionContext"] = sessionContext
-    localEmbeddScriptScope["lastCommandResult"] = lastCommandResult
+    globalEmbeddScriptScope["sessionContext"] = sessionContext
+    globalEmbeddScriptScope["lastCommandResult"] = lastCommandResult
 
     return eval(expression, globalEmbeddScriptScope, localEmbeddScriptScope)
