@@ -464,7 +464,7 @@ class SQLVisitor(SQLParserVisitor):
             self.isFinished = False
 
         # 需要输出的文件名
-        param = ctx.ECHO_OPEN().getText().partition(' ')[2]
+        param = ctx.ECHO().getText().partition(' ')[2]
         if param is not None:
             param = param.splitlines()[0]
             parsedObject.update({'param': str(param).strip()})
@@ -625,6 +625,8 @@ class SQLVisitor(SQLParserVisitor):
             commond = str(" ".join(commands)).strip()
             if commond.startswith('"') and commond.endswith('"'):
                 commond = commond[1:-1]
+            if commond.startswith("'") and commond.endswith("'"):
+                commond = commond[1:-1]
             parsedObject.update({"command": commond})
         if ctx.SSH_CONNECT() is not None:
             parsedObject.update({"action": "connect"})
@@ -801,26 +803,49 @@ class SQLVisitor(SQLParserVisitor):
             if ctx.DATA_SEEDFILE() is not None:
                 parsedObject.update({"option": "seedDir"})
                 if len(ctx.DATA_EXPRESSION()) != 0:
-                    parsedObject.update({"seedDir": str(ctx.DATA_EXPRESSION()[0].getText()).strip()})
+                    seedDir = str(ctx.DATA_EXPRESSION()[0].getText()).strip()
+                    if seedDir.startswith('"') and seedDir.endswith('"'):
+                        seedDir = seedDir[1:-1]
+                    elif seedDir.startswith("'") and seedDir.endswith("'"):
+                        seedDir = seedDir[1:-1]
+                    parsedObject.update({"seedDir": seedDir})
 
         if ctx.DATA_CONVERT() is not None:
             parsedObject.update({"action": "convert"})
             parsedObject.update({"sourceFileType": str(ctx.DATA_FILETYPE()[0].getText())})
             parsedObject.update({"targetFileType": str(ctx.DATA_FILETYPE()[1].getText())})
-            parsedObject.update({"sourceFile": str(ctx.DATA_EXPRESSION()[0].getText())})
-            parsedObject.update({"targetFile": str(ctx.DATA_EXPRESSION()[1].getText())})
+            sourceFile = str(ctx.DATA_EXPRESSION()[0].getText())
+            targetFile = str(ctx.DATA_EXPRESSION()[1].getText())
+            if sourceFile.startswith('"') and sourceFile.endswith('"'):
+                sourceFile = sourceFile[1:-1]
+            elif sourceFile.startswith("'") and sourceFile.endswith("'"):
+                sourceFile = sourceFile[1:-1]
+            if targetFile.startswith('"') and targetFile.endswith('"'):
+                targetFile = targetFile[1:-1]
+            elif targetFile.startswith("'") and targetFile.endswith("'"):
+                targetFile = targetFile[1:-1]
+            parsedObject.update({"sourceFile": sourceFile})
+            parsedObject.update({"targetFile": targetFile})
 
         if ctx.DATA_CREATE() is not None:
             parsedObject.update({"action": "create"})
             parsedObject.update({"fileType": str(ctx.DATA_FILETYPE()[0].getText())})
-            parsedObject.update({"targetFile": str(ctx.DATA_EXPRESSION()[0].getText())})
+            targetFile = str(ctx.DATA_EXPRESSION()[0].getText())
+            if targetFile.startswith('"') and targetFile.endswith('"'):
+                targetFile = targetFile[1:-1]
+            elif targetFile.startswith("'") and targetFile.endswith("'"):
+                targetFile = targetFile[1:-1]
+            parsedObject.update({"targetFile": targetFile})
             if ctx.DATA_ROWS() is not None:
                 parsedObject.update({"rowCount": int(ctx.DATA_INT().getText())})
+            else:
+                # 默认输出是1行
+                parsedObject.update({"rowCount": 1})
             columnExpression = ""
-            for column in ctx.DATACOLUMN_EXPRESSION():
-                columnExpression = columnExpression + str(column.getText())
-            if ctx.DATA_ROWS() is not None:
-                columnExpression = columnExpression.replace("\n", "")
+            if ctx.DATACOLUMN_CONTENT() is not None:
+                columnExpression = str(ctx.DATACOLUMN_CONTENT().getText()).strip()
+                if columnExpression.endswith(')'):
+                    columnExpression = columnExpression[:-1]
             parsedObject.update({"columnExpression": str(columnExpression)})
 
         # 处理错误信息
@@ -883,10 +908,6 @@ class SQLVisitor(SQLParserVisitor):
         for expression in ctx.SET_EXPRESSION():
             expression_list.append(str(expression.getText()))
 
-        if ctx.SET_AT():
-            parsedObject.update({'scope': "global"})
-        else:
-            parsedObject.update({'scope': "local"})
         if len(expression_list) >= 1:
             parsedObject.update({'optionName': expression_list[0]})
         if len(expression_list) >= 2:
@@ -1161,7 +1182,12 @@ class SQLVisitor(SQLParserVisitor):
             parsedObject.update({'expression': ""})
 
         if ctx.ASSERT_NAME() is not None:
-            parsedObject.update({'assertName': str(ctx.ASSERT_NAME().getText()).strip()})
+            assertName = str(ctx.ASSERT_NAME().getText()).strip()
+            if assertName.startswith('"') and assertName.endswith('"'):
+                assertName = assertName[1:-1]
+            if assertName.startswith("'") and assertName.endswith("'"):
+                assertName = assertName[1:-1]
+            parsedObject.update({'assertName': assertName})
         else:
             parsedObject.update({'assertName': None})
 
@@ -1406,3 +1432,89 @@ class SQLVisitor(SQLParserVisitor):
         self.parsedObject = parsedObject
         self.errorCode = errorCode
         self.errorMsg = errorMsg
+
+    def visitHelp(self, ctx: SQLParser.HelpContext):
+        parsedObject = {'name': 'HELP'}
+
+        parsedObject.update({'topic': ""})
+        if ctx.HELP_COMMAND() is not None:
+            parsedObject.update({'topic': str(ctx.HELP_COMMAND().getText()).strip().upper()})
+
+        # 获取错误代码
+        errorCode = 0
+        errorMsg = None
+        if ctx.exception is not None:
+            errorCode = -1
+            errorMsg = ctx.exception.message
+
+        self.parsedObject = parsedObject
+        self.errorCode = errorCode
+        self.errorMsg = errorMsg
+
+    def visitMonitor(self, ctx: SQLParser.MonitorContext):
+        parsedObject = {'name': 'MONITOR'}
+
+        if ctx.MONITOR_MANAGER() is not None:
+            if ctx.MONITOR_ON() is not None:
+                parsedObject.update({'action': 'startManager'})
+                if ctx.MONITOR_WORKERS() is not None:
+                    workerThreads = int(ctx.MONITOR_EXPRESSION()[0].getText())
+                else:
+                    workerThreads = None
+                parsedObject.update({'workerThreads': workerThreads})
+            if ctx.MONITOR_OFF() is not None:
+                parsedObject.update({'action': 'stopManager'})
+        if ctx.MONITOR_CREATE() is not None:
+            parsedObject.update({'action': 'createTask'})
+            nPos = 0
+            param = {}
+            paramKey = None
+            if len(ctx.MONITOR_EXPRESSION()) % 2 == 0:
+                # 省略了taskName
+                parsedObject.update({"taskName": "NO-NAME"})
+                for expression in ctx.MONITOR_EXPRESSION():
+                    if paramKey is None:
+                        paramKey = str(expression.getText()).strip()
+                    else:
+                        paramValue = str(expression.getText()).strip()
+                        param[paramKey.upper()] = paramValue
+                        paramKey = None
+                    nPos = nPos + 1
+            else:
+                for expression in ctx.MONITOR_EXPRESSION():
+                    if nPos == 0:
+                        parsedObject.update({"taskName": expression.getText().strip()})
+                    else:
+                        if paramKey is None:
+                            paramKey = str(expression.getText()).strip()
+                        else:
+                            paramValue = str(expression.getText()).strip()
+                            param[paramKey.upper()] = paramValue
+                            paramKey = None
+                    nPos = nPos + 1
+            parsedObject.update({"param": param})
+        if ctx.MONITOR_START() is not None:
+            parsedObject.update({"action": "startTask"})
+            taskName = str(ctx.MONITOR_EXPRESSION()[0].getText()).strip()
+            parsedObject.update({"taskName": taskName})
+        if ctx.MONITOR_STOP() is not None:
+            parsedObject.update({"action": "stopTask"})
+            taskName = str(ctx.MONITOR_EXPRESSION()[0].getText()).strip()
+            parsedObject.update({"taskName": taskName})
+        if ctx.MONITOR_REPORT() is not None:
+            parsedObject.update({"action": "reportTask"})
+            taskName = str(ctx.MONITOR_EXPRESSION()[0].getText()).strip()
+            parsedObject.update({"taskName": taskName})
+        if ctx.MONITOR_LIST() is not None:
+            parsedObject.update({"action": "listTask"})
+
+        # 获取错误代码
+        errorCode = 0
+        errorMsg = None
+        if ctx.exception is not None:
+            errorCode = -1
+            errorMsg = ctx.exception.message
+
+        self.parsedObject = parsedObject
+        self.errorCode = errorCode
+        self.errorMsg = errorMsg
